Class: Aws::KinesisVideoWebRTCStorage::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KinesisVideoWebRTCStorage::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kinesisvideowebrtcstorage/client.rb
Overview
An API client for KinesisVideoWebRTCStorage. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KinesisVideoWebRTCStorage::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#join_storage_session(params = {}) ⇒ Struct
<note markdown=“1”> Before using this API, you must call the ‘GetSignalingChannelEndpoint` API to request the WEBRTC endpoint.
-
#join_storage_session_as_viewer(params = {}) ⇒ Struct
Join the ongoing one way-video and/or multi-way audio WebRTC session as a viewer for an input channel.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
633 634 635 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 633 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
636 637 638 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 636 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 606 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KinesisVideoWebRTCStorage') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kinesisvideowebrtcstorage' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#join_storage_session(params = {}) ⇒ Struct
<note markdown=“1”> Before using this API, you must call the ‘GetSignalingChannelEndpoint` API to request the WEBRTC endpoint. You then specify the endpoint and region in your `JoinStorageSession` API request.
</note>
Join the ongoing one way-video and/or multi-way audio WebRTC session as a video producing device for an input channel. If there’s no existing session for the channel, a new streaming session needs to be created, and the Amazon Resource Name (ARN) of the signaling channel must be provided.
Currently for the ‘SINGLE_MASTER` type, a video producing device is able to ingest both audio and video media into a stream. Only video producing devices can join the session and record media.
Both audio and video tracks are currently required for WebRTC ingestion.
Current requirements:
* Video track: H.264
-
Audio track: Opus
The resulting ingested video in the Kinesis video stream will have the following parameters: H.264 video and AAC audio.
Once a master participant has negotiated a connection through WebRTC, the ingested media session will be stored in the Kinesis video stream. Multiple viewers are then able to play back real-time media through our Playback APIs.
You can also use existing Kinesis Video Streams features like ‘HLS` or `DASH` playback, image generation via [GetImages], and more with ingested WebRTC media.
<note markdown=“1”> S3 image delivery and notifications are not currently supported.
</note>
<note markdown=“1”> Assume that only one video producing device client can be associated with a session for the channel. If more than one client joins the session of a specific channel as a video producing device, the most recent client request takes precedence.
</note>
**Additional information**
-
Idempotent - This API is not idempotent.
-
**Retry behavior** - This is counted as a new API call.
-
**Concurrent calls** - Concurrent calls are allowed. An offer is sent once per each call.
[1]: docs.aws.amazon.com/kinesisvideostreams/latest/dg/gs-getImages.html
553 554 555 556 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 553 def join_storage_session(params = {}, = {}) req = build_request(:join_storage_session, params) req.send_request() end |
#join_storage_session_as_viewer(params = {}) ⇒ Struct
Join the ongoing one way-video and/or multi-way audio WebRTC session as a viewer for an input channel. If there’s no existing session for the channel, create a new streaming session and provide the Amazon Resource Name (ARN) of the signaling channel (‘channelArn`) and client id (`clientId`).
Currently for ‘SINGLE_MASTER` type, a video producing device is able to ingest both audio and video media into a stream, while viewers can only ingest audio. Both a video producing device and viewers can join a session first and wait for other participants. While participants are having peer to peer conversations through WebRTC, the ingested media session will be stored into the Kinesis Video Stream. Multiple viewers are able to playback real-time media.
Customers can also use existing Kinesis Video Streams features like ‘HLS` or `DASH` playback, Image generation, and more with ingested WebRTC media. If there’s an existing session with the same `clientId` that’s found in the join session request, the new request takes precedence.
597 598 599 600 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 597 def join_storage_session_as_viewer(params = {}, = {}) req = build_request(:join_storage_session_as_viewer, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
626 627 628 |
# File 'lib/aws-sdk-kinesisvideowebrtcstorage/client.rb', line 626 def waiter_names [] end |